@@ -7,13 +7,6 @@ from loguru import logger
 env = Env()
 env.read_env()
 
-# definition of logs
-NEED_LOG_TESTER = False
-NEED_LOG_GETTER = False
-NEED_LOG_SERVER = False
-NEED_LOG_REDIS = False
-
-
 # definition of flags
 IS_WINDOWS = platform.system().lower() == 'windows'
 
@@ -39,21 +32,6 @@ APP_PROD_METHOD_TORNADO = 'tornado'
 APP_PROD_METHOD_MEINHELD = 'meinheld'
 APP_PROD_METHOD = env.str('APP_PROD_METHOD', APP_PROD_METHOD_GEVENT).lower()
 
-# only save anonymous proxy
-TEST_ANONYMOUS = env.bool('TEST_ANONYMOUS', True)
-# TEST_HEADERS = env.json('TEST_HEADERS', {
-#     'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.71 Safari/537.36',
-# })
-TEST_VALID_STATUS = env.list('TEST_VALID_STATUS', [200, 206, 302])
-
-# definition of api
-API_THREADED = env.bool('API_THREADED', True)
-
-# flags of enable
-ENABLE_TESTER = env.bool('ENABLE_TESTER', True)
-ENABLE_GETTER = env.bool('ENABLE_GETTER', True)
-ENABLE_SERVER = env.bool('ENABLE_SERVER', True)
-
 
 ENABLE_LOG_FILE = env.bool('ENABLE_LOG_FILE', True)
 ENABLE_LOG_RUNTIME_FILE = env.bool('ENABLE_LOG_RUNTIME_FILE', True)
